//
//  AASFileLoadOperation.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 3/6/08.
//  Copyright 2008 __MyCompanyName__. All rights reserved.
//

/* This NSOperation subclass reads directory contents from disk, creates file objects for each file, and adds the file to an array based on optional file filter criteria. The array can be safely accessed during loading by locking the returned NSLock object, or at any time after the operation is finished. File objects in the loading array are not added in any particular order. If recursively loading subdirectories, a directory filter can be used to determine what should be considred a valid directory, and where that directory's contents are. Recursively loaded contents are all added individually to the single loading array and no order is guaranteed (eg. they will not be grouped by directory). Recursive operations only iterate through a directory once; if the directory filter returns the same directory twice (typically, when you're iterating through directories that contain aliases or symbolic links to directories that show up elsewhere down the same tree and your filter instructs the operation to follow those links) it will be ignored. Files in the loading array are guaranteed to be unique (no duplicates) for recursive loads only if the loading array has not been modified while the operation has run - if it has, it is possible that files might be duplicated if they appeared in the setFiles: array AND were loaded from a directory during the recursive load. */


#import <Cocoa/Cocoa.h>
#import "AASLoadingOperation.h"

@class AASFile;
@class AASFileFilter;
@class AASDirectoryFilter;


@interface AASFileLoadOperation : AASLoadingOperation {	
	NSArray *filesToIterate;
	AASFile *loadingDirectory;
	
	AASFileFilter *fileFilter;
	AASDirectoryFilter *directoryFilter;
	
	CFIndex depth;
	BOOL recursive;
}


/* Designated initializer. */
- (id)init;


/* Set or get the file object representing the directory whose contents are to be loaded for a non-recursive operation. The class of 'loadingDirectory' determines the class of created and put into the loading array (if you initialize this with a custom subclass of AASFile, the objects will be of that same class). Must be set before the operation has ben added to an operation queue, and should not be changed after that. */
@property(retain) AASFile *loadingDirectory;

/* Set or get an array containing file objects representing the directories whose contents are to be loaded for a recursive operation. The files should be AASFile objects (or a subclass). All items in the array (including those which do not represent directories) are themselves filtered by the file filter (if one has been set) and added to the loading array - this way, you can easily pass an array containing file objects for an entire directory's contents, and get back all those contents plus subcontents. The class of the file objects set here determines the class of objects loaded into the loading array (if you initialize this with a custom subclass of AASFile, the loaded objects will be of that same class). Must be set before the operation has ben added to an operation queue, and should not be changed after that. */
@property(copy) NSArray *filesToIterate;



/* Set or get a file filter that will tell the operation whether or not to include a file in the loading queue. Do not set after the operation has been added to an operation queue. */
@property(retain) AASFileFilter *fileFilter;



/* Set or get whether or not this operation is to be recursive. Default is NO. If the operation will be recursive, filesToIterate must be set, otherwise loadingDirectory must be set. Do not set after the operation has been added to an operation queue. */
@property BOOL recursive;




// Recursive operations only

/* Set or get an AASDirectoryFilter (or subclass) that this operation can use to determine what is a directory and where its contents are. Do not set after the operation has been added to an operation queue. */
@property(retain) AASDirectoryFilter *directoryFilter;

/* Set or get the how many levels deep the recursive operation should go. '-1' is unlimited. '0' essentially will not do more than filter the files already given. Do not set after the AASFileLoadOperation has been added to an operation queue. */
@property CFIndex depth;

	
@end
