/*
 *  GBUtilityFunctions.h
 *  
 *
 *  Created by Andreas Schwarz on Mon Jun 03 2002.
 *  Copyright (c) 2002 Andreas Schwarz. All rights reserved.
 *
 */

#ifndef __GBUTILITYFUNCTIONS__
#define __GBUTILITYFUNCTIONS__

#include <sys/types.h>
#include <sys/stat.h>

#import <Cocoa/Cocoa.h>

@class GBFile;

/* File information functions */

    /* Uses stat() to get the modification date fo a file; returns NO if there is any error */
BOOL GBGetStatModificationDate(NSString *file, struct timespec *spec);
    
    /* Returns YES if the file at the specified path is an alias file (symlinks don't count) */
BOOL GBFileAtPathIsAlias(NSString *path);
            
    /* Retuns YES if there is a valid directory at the specified path (any directory that isn't a package/bundle).  This resolves symlinks and aliases before looking, so it will return YES for a file that is an alias or symlink to a folder. */
BOOL GBIsValidDirectoryAtPath(NSString *path);



/* File manipulation functions */

    /* Uses appleevents to make an alias of the specified file within the specified parent directory */
BOOL GBCreateAliasFile(NSString *file, NSString *aliasParent);
    
    /* Deletes the resource fork of the file at the specified path */
void GBDeleteResourceFork(NSString *path);
    
    /* Sets whether the specified file's extension should be hidden */
void GBSetFileExtensionHidden(NSString *file, BOOL hidden);



/* Miscellaneous utility functions */

/* Takes an array of UTIs (such as you'd get from +[NSImage imageTypes]) and returns YES if inUTI conforms to one of those UTIs. */
BOOL GBUTTypeConformsToArray(CFStringRef inUTI, NSArray *testUTIs);
    
    /* Creates a Carbon FSSpec for the specified path.  Don't use this unless absolutely necessary (I don't think the FSSpec handles filenames longer than 31 characters, or something like that, and I think FSRef was created as a replacement.  Unfortunately there are a few things that still require FSSpecs, notably Quicktime) */
BOOL GBFSSpecForPath(FSSpec *spec, NSString *path);

    /* Creates a Carbon FSSpec for a specified FSRef */
BOOL GBFSSpecForFSRef(FSSpec *spec, FSRef *ref);

    /* When passed a path to an alias or symlink file, it will return the path (an autoreleased NSString) to the file it was pointing to.  Otherwise it just returns the original path */
NSString * GBOriginalPathForAlias(NSString *pathToResolve);

    /* Returns the path of the file an AliasHandle points to */
NSString * GBOriginalPathForAliasHandle(AliasHandle *alias);

    /* Given a pointer to an AliasHandle and a path string, this makes the alias */
BOOL GBAliasHandleForPath(AliasHandle *alias, NSString *path);

    /* Searches the array (which should be an array of NSStrings) and returns YES if it contains any string equal to the specified string (using isEqualToString:) */
BOOL GBSearchArrayForString(NSArray *array, NSString *string);

    /* Replaces all occurances of a specified substring (badString) in searchString with a new string (newString).  Used by the "GBCreateCleanFileName" function to replace illegal characters with dashes */
void GBReplaceAllOccurrancesOfString(CFMutableStringRef searchString, CFStringRef badString, CFStringRef newString);
    
    /* Takes an NSString that should represent a file name (not an entire path, because it replaces slashes) and replaces any illegal characters with dashes (good to use when the user renames a file).  Currently, it will replace: "/", ":", and "._" */
NSString * GBCreateCleanFileName(NSString *filename);

    /* Uses appleevents to tell the Finder to open a new window */
void GBOpenNewFinderWindow();

    /* Uses FSFindFolder to find the appropriate folder and return the appropriate path */
NSString *GBUserPicturesDirectoryPath();
NSString *GBUserPreferencesDirectoryPath();
NSString *GBPreferencesFilePath();



/* Drawing functions */

    /* Draws a shadow behind an attributed string.  Very, very slow, never use where efficiency matters. */
void GBDrawShadowOfStringInRect(NSAttributedString * str, NSRect rect, NSColor *color, BOOL flipped, int radius, int quality, NSSize offset);

    /* Draws a message box, kind of like a message window, except inside a view. */
void GBDrawMessageBox(NSString *message, NSRect frame, NSView *view);

    /* Draws a message box with a file's name and icon inside a view. */
void GBDrawMessageBoxWithFile(NSString *message, NSRect frame, NSView *view, GBFile *file);


#endif /* __GBUTILITYFUNCTIONS__ */

